## Working with neptoon in python

There may be times when you want to work with neptoon directly with your favourite python IDE.

A good starting point for working with neptoon in python is to checkout the [examples](neptoon-examples.md). In this section we give advice on how to install and get going with neptoon as well as how to get the example files on your computer to start playing with.

The rest of this section will be tasked with explaining in some more detail how each of the steps in the [workflow](workflow-description.md) operate.